#
# spec file for package deepin-control-center
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name dde-control-center
%if 0%{?is_opensuse}
    %define  distribution  openSUSE-Edition
%else
    %define  distribution  SUSE-Edition
%endif

Name:           deepin-control-center
Version:        5.5.143
Release:        1.10
Summary:        New control center for Linux Deepin
License:        LGPL-3.0-or-later
URL:            https://github.com/linuxdeepin/dde-control-center
Source0:        https://github.com/linuxdeepin/dde-control-center/archive/%{version}/%{_name}-%{version}.tar.gz
# PATCH-FOR-OPENSUSE deepin-control-center-no-user-experience.patch hillwood@opensuse.org
# Disable User Experience Program on openSUSE
Patch0:         %{name}-no-user-experience.patch
# PATCH-FOR-OPENSUSE systeminfo-deepin-icon.patch hillwood@opensuse.org - Use deepin icons instead of UOS
Patch1:         systeminfo-deepin-icon.patch
# PATCH-FOR-OPENSUSE remove-auth.patch
# Patch3:         remove-auth.patch
# PATCH-FOR-UPSTREAM fix-include-directories.patch hillwood@opensuse.org - Fix boo#1200959
# Patch4:         fix-include-directories.patch
Group:          System/GUI/Other
BuildRequires:  cmake
BuildRequires:  deepin-desktop-base
BuildRequires:  deepin-pw-check-devel
BuildRequires:  desktop-file-utils
BuildRequires:  dtkcommon >= 5.5.20
BuildRequires:  dtkcore
BuildRequires:  fdupes
BuildRequires:  gtest
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libQt5Widgets-private-headers-devel
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtwayland-private-headers-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5NetworkManagerQt)
BuildRequires:  cmake(KF5Wayland)
BuildRequires:  cmake(PolkitQt5-1)
BuildRequires:  cmake(Qt5XkbCommonSupport)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5WaylandClient)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(dareader)
BuildRequires:  pkgconfig(dde-network-utils)
BuildRequires:  pkgconfig(dframeworkdbus) >= 2.0
BuildRequires:  pkgconfig(dtkcore) >= 5.0.0
BuildRequires:  pkgconfig(dtkwidget) >= 5.0.0
BuildRequires:  pkgconfig(gsettings-qt)
BuildRequires:  pkgconfig(udisks2-qt5)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(xcb-ewmh)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xkbcommon)
Requires:       deepin-account-faces
Requires:       deepin-api
Requires:       deepin-daemon
Requires:       deepin-start
Requires:       libdeepin_pw_check1
Requires:       libqt5-qdbus
Requires:       qt5integration
Requires:       redshift
Recommends:     %{name}-data
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The deepin-control-center is the control panel of Deepin Desktop.

%package data
Summary:        Data of deepin-control-center
Requires:       %{name} = %{version}
BuildArch:      noarch

%description data
The deepin-control-center is the control panel of Deepin Desktop.

deepin-control-center-data is the data of deepin-control-center.

%package devel
Summary:        Development tools for deepin-control-center
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}

%description devel
The deepin-control-center-devel package contains the header files and developer
docs for deepin control center.

%lang_package

%prep
%autosetup -p1 -n %{_name}-%{version}
sed -i 's|lrelease|lrelease-qt5|g' translate_generation.sh
sed -i 's/DESTINATION lib/DESTINATION ${CMAKE_INSTALL_LIBDIR}/g' src/frame/CMakeLists.txt
sed -i 's|qdbus|qdbus-qt5|g' com.deepin.dde.ControlCenter.service dde-control-center-wapper
sed -i '/set(VERSION/s|4.0|%{version}-%{distribution}|' abrecovery/CMakeLists.txt \
       src/develop-tool/CMakeLists.txt \
       src/frame/CMakeLists.txt \
       src/reboot-reminder-dialog/CMakeLists.txt

%build
%cmake -DDCC_DISABLE_GRUB=YES \
       -DDISABLE_SYS_UPDATE=YES \
       -DCC_DISABLE_FEEDBACK=YES \
       -DDISABLE_ACTIVATOR=YES \
       -DCC_DISABLE_LANGUAGE=YES \
       -DCVERSION=%{version}-%{distribution}

%cmake_build

%install
%cmake_install

sed -i 's/OnlyShowIn=/X-DEEPIN-OnlyShowIn/g' \
%{buildroot}%{_datadir}/applications/%{_name}.desktop
chmod -x %{buildroot}%{_datadir}/applications/%{_name}.desktop
%suse_update_desktop_file -r %{_name} Settings DesktopSettings X-SuSE-Core-System
rm -rf %{buildroot}%{_datadir}/polkit-1/actions/com.deepin.controlcenter.develop.policy
rm -rf %{buildroot}%{_datadir}/dman

%fdupes %{buildroot}

%files
%defattr(-,root,root,-)
%doc README.md CHANGELOG.md docs/internaltest.md
%license LICENSE
%{_bindir}/%{_name}
%{_bindir}/%{_name}-wapper
%{_bindir}/abrecovery
%{_sysconfdir}/xdg/autostart/deepin-ab-recovery.desktop
%{_datadir}/applications/%{_name}.desktop
%{_datadir}/dbus-1/services/*.service
%{_libdir}/libdccwidgets.so
%dir %{_prefix}/lib/dde-grand-search-daemon
%dir %{_prefix}/lib/dde-grand-search-daemon/plugins
%{_prefix}/lib/dde-grand-search-daemon/plugins/searcher
%dir %{_datadir}/%{_name}/
%{_datadir}/%{_name}/%{_name}.conf
%{_datadir}/glib-2.0/schemas/com.deepin.dde.control-center.gschema.xml
%dir %{_datadir}/dsg
%dir %{_datadir}/dsg/configs
# %dir %{_datadir}/dsg/configs/dde-control-center
%dir %{_datadir}/dsg/configs/org.deepin.dde.control-center
# %{_datadir}/dsg/configs/dde-control-center/*.json
%{_datadir}/dsg/configs/org.deepin.dde.control-center/*.json
# %{_datadir}/dsg/apps/dde-control-center
# %{_datadir}/polkit-1/actions/com.deepin.controlcenter.develop.policy

%files data
%defattr(-,root,root,-)
%{_datadir}/%{_name}/*db
%{_datadir}/dict/MainEnglishDictionary_ProbWL.txt

%files devel
%defattr(-,root,root,-)
%{_includedir}/%{_name}
%{_libdir}/cmake/DdeControlCenter

%files lang
%defattr(-,root,root,-)
%{_datadir}/%{_name}/translations/

%changelog
* Wed Aug 24 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.143
  * Add switch-kdb-layout shortcut
  * Add dconfig configuration for airplane mode
  * Change password policy
  * Update translations
  * Fix bugs
- Drop remove-auth.patch and fix-include-directories.patch, fixed by
  upstream.
* Tue Jun 28 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.83
  * Optimize wayland support
  * Fix bugs
  * Update documents
  * Update translations
- Add fix-include-directories.patch, fix boo#1200959
* Tue Apr  5 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.16.2
  * Add sound device manager
  * Update manaul document
  * Add computer name in system info
  * Add hotspot button config
  * Update translations
  * Fix bugs
- Drop fix-return-type.patch, fixed by upstream
- Drop fix-qDBusRegisterMetaType-error.patch, merged by upstream
- Add remove-auth.patch
* Wed Feb 23 2022 Hillwood Yang <hillwood@opensuse.org>
- No longer need deepin-dock-devel
* Sat Jan 29 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.109
  * Add global search for system shortcuts
  * Add search feature for default application setting tab
  * optimize ui
  * Fix bugs
  * Update translations
* Thu Oct 28 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.77
  * Add hotspot and bluetooth config buttons
  * Add AccessibleName
  * Update translations
  * Optimize ui
  * Fix bugs
- Add fix-return-type.patch
* Sat Aug 28 2021 Hillwood Yang <hillwood@opensuse.org>
- Disable language module.
* Sun Jul 25 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.47
  * Fix bugs
  * Use DBus to provide timezoon
- Add fix-qDBusRegisterMetaType-error.patch.
* Thu Apr 15 2021 Hillwood Yang <hillwood@opensuse.org>
- Add deepin-control-center-no-user-experience.patch: Disable User
  Experience Program
* Tue Apr 13 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.17
  * Optimize userface
  * Optimize touchscreen
  * Fix bug
  * Update translations
* Sat Apr 10 2021 Hillwood Yang <hillwood@opensuse.org>
- Use qdbus-qt5 instead of qdbus
* Tue Mar 16 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.9
  * Add important filelist
  * Fix bugs
  * Update translations
  * add search support for privacy policy page
* Tue Feb 23 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.3.0.82
  * The fresh ui
  * Fix bugs
* Sat Jul 20 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 4.10.14
  * Fix ldap: login not enabled after joining domain
  * Fix nav: missing disable systeminfo module
  * Fix sync: typo DISALBE -> DISABLE
  * Fix missing build macro
  * Fix remove network check
  * navbar: avoid tip grab focus
  * Fix accounts: cannot modify user password
  * Fix network: Abnormal interface of hostpot
  * update license
  * Sync: add config files
  * Fix incorrect layout of various pages
  * Fix set word wrap on switch widget construction
  * Fix sync bug
  * Fix missing smarttips spacing
  * Fix switch widget caption text overflows
  * Fix dbus method 'rect' returns wrong results after screen rotation
  * Fix dbus: check windowhandle
  * Add sync
  * long processor name screws up layout
  * Fix fprintd: refresh device when enter user detail page again
  * Fix accounts: not hide error tip
  * Fix sw: missing mieee
  * Fix missing polkit policy file
  * Fix display: Adjust the resolution when merging the screen, destroy the merge
  * Shortcut: add restore defaults button
  * Fix Sound: typo Logout
  * Fix Update notifications are not hidden
  * Fix network: refresh loading icon not align center
  * Fix crash when startup in terminal
  * Fix rotate dialog postion is wrong in 2D mode
  * Fix ipv4 subnet mask valid checkup
  * Fix wireless activating indicator not align in vertical
  * Fix display: did not check the multi scale ratio
- Add fix-redefinition-error.patch, fix build.
* Wed Apr 17 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 4.9.13
  * Fix wifi list sort algorithm
  * Fix miracast: wrong display nodevice item
  * Fix sound: missing page title
  * Fix display: exit rotate disloag after press Esc key
  * Multiple screen can not show
  * Display: use a profile to control multi-screen scale ratio
  * Sound: hide some sound effect when not laptop
  * Fix main window geometry is wrong
  * Fix Sound: skip not need values
  * Fix arm: disable power module
  * Fix hide option for individual scaling unless extend or custom configuration
    is in use
  * Fix keep the lenght of ssid among 1-32
  * Fix compile error caused by dtk
  * Fix translate failed in searchinput widget
  * Fix reboot-reminder-dialog install path error
  * Initial work on scaling monitors individually
* Fri Mar 16 2018 hillwood@opensuse.org
- Update version to 4.4.0
  * Fix bug.
  * Features update for accounts, display, frame, keyboard and so on.
    Please see more detail in CHANGELOG.md.
* Thu Dec  7 2017 hillwood@opensuse.org
- Add openSUSE log and information in system information.
* Thu Nov 30 2017 hillwood@opensuse.org
- Update 4.3.7
  * update:  not update checkupdate status
  * display:  initializing value
  * network:  update select svg
  * account:  user name is empty when display name
  * display:  replace DImageButton to QLabel of brightnessitem
  * network:  add show password button
  * widget:  add passwdeditwidget
  * file:  pics permission error
  * etc ....
  * See more in CHANGELOG.md
* Fri Nov 17 2017 hillwood@opensuse.org
- Cleanup spec.
  * Add Group tag.
  * Use %%suse_update_desktop_file.
- Split lang, data and plugins package.
* Tue Oct  3 2017 sensor.wen@gmail.com
- Initial package.
